@@ -189,6 +189,11 @@ class CommentResource(BaseModelResource):
             )
         return comment
 
+    def update_data(self, data, instance_id):
+        data = super().update_data(data, instance_id)
+        data["editor_id"] = persons_service.get_current_user_raw().id
+        return data
+
     @jwt_required()
     def delete(self, instance_id):
         """
