@@ -1,7 +1,12 @@
 from zou.app.services import (
+    assets_service,
     base_service,
     projects_service,
     notifications_service,
+    assets_service,
+    shots_service,
+    edits_service,
+    tasks_service,
 )
 from zou.app.utils import (
     date_helpers,
@@ -15,8 +20,7 @@ from zou.app.models.entity import Entity, EntityLink, EntityConceptLink
 from zou.app.models.entity_type import EntityType
 from zou.app.models.preview_file import PreviewFile
 from zou.app.models.project import Project
-from zou.app.models.task import assignees_table
-from zou.app.models.task import Task
+from zou.app.models.task import Task, TaskPersonLink
 
 from zou.app import db
 
@@ -108,12 +112,13 @@ def update_entity_preview(entity_id, preview_file_id):
     if entity is None:
         raise EntityNotFoundException
 
+    entity_id = str(entity.id)
     preview_file = PreviewFile.get(preview_file_id)
     if preview_file is None:
         raise PreviewFileNotFoundException
 
     entity.update({"preview_file_id": preview_file.id})
-    clear_entity_cache(str(entity.id))
+    clear_entity_cache(entity_id)
     events.emit(
         "preview-file:set-main",
         {"entity_id": entity_id, "preview_file_id": preview_file_id},
@@ -125,12 +130,36 @@ def update_entity_preview(entity_id, preview_file_id):
         entity_type_name = entity_type.name.lower()
     events.emit(
         "%s:update" % entity_type_name,
-        {"%s_id" % entity_type_name: str(entity.id)},
+        {"%s_id" % entity_type_name: entity_id},
         project_id=str(entity.project_id),
     )
+    assets_service.clear_asset_cache(entity_id)
+    edits_service.clear_edit_cache(entity_id)
+    shots_service.clear_shot_cache(entity_id)
+    shots_service.clear_episode_cache(entity_id)
+    shots_service.clear_sequence_cache(entity_id)
     return entity.serialize()
 
 
+def get_for_entity_from_task(task):
+    """
+    Return the entity type name for given task. All asset types are returned
+    as "Asset".
+    """
+    entity = get_entity(task["entity_id"])
+    entity_type = get_entity_type(entity["entity_type_id"])
+    for_entity = entity_type["name"]
+    if for_entity.lower() not in [
+        "shot",
+        "sequence",
+        "episode",
+        "edit",
+        "concept",
+    ]:
+        for_entity = "Asset"
+    return for_entity
+
+
 def get_entities_for_project(
     project_id,
     entity_type_id,
@@ -227,7 +256,7 @@ def get_entities_and_tasks(criterions={}):
 
     query = (
         Entity.query.outerjoin(Task, Task.entity_id == Entity.id)
-        .outerjoin(assignees_table)
+        .outerjoin(TaskPersonLink)
         .add_columns(
             Task.id,
             Task.task_type_id,
@@ -240,8 +269,11 @@ def get_entities_and_tasks(criterions={}):
             Task.end_date,
             Task.start_date,
             Task.due_date,
+            Task.done_date,
             Task.last_comment_date,
-            assignees_table.columns.person,
+            Task.last_preview_file_id,
+            Task.difficulty,
+            TaskPersonLink.person_id,
         )
     )
 
@@ -269,7 +301,10 @@ def get_entities_and_tasks(criterions={}):
         task_end_date,
         task_start_date,
         task_due_date,
+        task_done_date,
         task_last_comment_date,
+        task_last_preview_file_id,
+        task_difficulty,
         person_id,
     ) in query.all():
         entity_id = str(entity.id)
@@ -305,13 +340,16 @@ def get_entities_and_tasks(criterions={}):
                         "entity_id": entity_id,
                         "end_date": task_end_date,
                         "due_date": task_due_date,
+                        "done_date": task_done_date,
                         "duration": task_duration,
                         "is_subscribed": subscription_map.get(task_id, False),
                         "last_comment_date": task_last_comment_date,
+                        "last_preview_file_id": task_last_preview_file_id,
                         "priority": task_priority or 0,
                         "real_start_date": task_real_start_date,
                         "retake_count": task_retake_count,
                         "start_date": task_start_date,
+                        "difficulty": task_difficulty,
                         "task_status_id": str(task_status_id),
                         "task_type_id": str(task_type_id),
                         "assignees": [],
@@ -327,6 +365,20 @@ def get_entities_and_tasks(criterions={}):
     return list(entity_map.values())
 
 
+def get_entity_tasks(entity):
+    """
+    Get all tasks for a given entity.
+    """
+    entity_type = get_entity_type(entity_type_id=entity["entity_type_id"])
+    entity_type_name = entity_type["name"]
+    if assets_service.is_asset_type(entity_type):
+        entity_type_name = "Asset"
+    get_tasks = getattr(
+        tasks_service, "get_tasks_for_" + entity_type_name.lower()
+    )
+    return get_tasks(entity["id"])    
+
+
 def remove_entity_link(link_id):
     try:
         link = EntityLink.get_by(id=link_id)
@@ -379,7 +431,7 @@ def get_linked_entities_with_tasks(entity_id):
     query = (
         Entity.query.join(Project, Project.id == Entity.project_id)
         .outerjoin(Task, Task.entity_id == Entity.id)
-        .outerjoin(assignees_table)
+        .outerjoin(TaskPersonLink)
         .join(EntityType)
         .add_columns(
             Task.id,
@@ -396,7 +448,7 @@ def get_linked_entities_with_tasks(entity_id):
             Task.last_comment_date,
             Task.nb_assets_ready,
             Task.assigner_id,
-            assignees_table.columns.person,
+            TaskPersonLink.person_id,
             Project.id,
             Project.name,
             EntityType.name,
